@@ -65,7 +65,7 @@ class SpacyNERAnnotator(AnnotatorBase):
             for sent, asent in zip(document.sentences, asents):
                 for ent in asent.ents:
                     start = sent.start + ent.start_char
-                    end = sent.start + + ent.end_char
+                    end = sent.start + ent.end_char
                     terms = []
                     if linker is not None:
                         for umls_ent in ent._.kb_ents:
